@@ -377,6 +377,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
 	free(type_tag);
 	free(path);
 	free(action);
+
+	g_object_unref(task_thread);
 	
 	return(start_response);
       }
@@ -411,6 +413,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
 	free(path);
 	free(action);
 
+	g_object_unref(task_thread);
+
 	return(start_response);
       }
     }else if(!strncmp(path + path_offset, "/AgsAudio", 9)){
@@ -445,6 +449,10 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
 	  free(path);
 	  free(action);
 	  
+	  g_object_unref(task_thread);
+	  g_list_free_full(start_list,
+			   g_object_unref);
+	  
 	  return(start_response);
 	}
 	
@@ -453,7 +461,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
       
 	path_offset = index(path + path_offset, ']') - path + 1;
 	
-	g_list_free(start_list);
+	g_list_free_full(start_list,
+			 g_object_unref);
       }else if(path[path_offset + 1] == '"'){
 	gchar *audio_name;
 	gchar *offset;
@@ -476,6 +485,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
 	  free(path);
 	  free(action);
 	  
+	  g_object_unref(task_thread);
+	  
 	  return(start_response);
 	}
 
@@ -495,7 +506,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
 
 	path_offset = path_offset + strlen(audio_name) + 2;
 	
-	g_list_free(start_list);
+	g_list_free_full(start_list,
+			 g_object_unref);
       }else{
 	osc_response = ags_osc_response_new();
 	start_response = g_list_prepend(start_response,
@@ -512,6 +524,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
 	free(path);
 	free(action);
 
+	g_object_unref(task_thread);
+
 	return(start_response);
       }
 
@@ -545,6 +559,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
 	free(path);
 	free(action);
 
+	g_object_unref(task_thread);
+
 	return(start_response);
       }
     }
@@ -562,6 +578,8 @@ ags_osc_action_controller_real_run_action(AgsOscActionController *osc_action_con
   free(path);
   free(action);
   
+  g_object_unref(task_thread);
+
   return(start_response);
 }
 
