@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2018 Joël Krähemann
+ * Copyright (C) 2005-2019 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -1302,7 +1302,7 @@ void
 ags_play_lv2_audio_run_run_pre(AgsRecall *recall)
 {
   AgsAudio *audio;
-  AgsChannel *output, *input;
+  AgsChannel *start_output, *start_input;
   AgsChannel *channel;
   AgsChannel *selected_channel;
   AgsRecycling *recycling;
@@ -1383,22 +1383,20 @@ ags_play_lv2_audio_run_run_pre(AgsRecall *recall)
   
   /* get some fields */
   g_object_get(audio,
-	       "output", &output,
-	       "input", &input,
+	       "output", &start_output,
+	       "input", &start_input,
 	       NULL);
-  g_object_unref(output);
-  g_object_unref(input);
-  
+
   /* get channel */
-  selected_channel = ags_channel_nth(output,
+  selected_channel = ags_channel_nth(start_output,
 				     audio_channel);
   
 #if 0
   if(ags_audio_test_behaviour_flags(audio, AGS_SOUND_BEHAVIOUR_DEFAULTS_TO_INPUT)){
-    selected_channel = ags_channel_nth(input,
+    selected_channel = ags_channel_nth(start_input,
 				       audio_channel);
   }else{
-    selected_channel = ags_channel_nth(output,
+    selected_channel = ags_channel_nth(start_output,
 				       audio_channel);
   }
 #endif
@@ -1407,7 +1405,6 @@ ags_play_lv2_audio_run_run_pre(AgsRecall *recall)
   g_object_get(selected_channel,
 	       "first-recycling", &recycling,
 	       NULL);
-  g_object_unref(recycling);
   
   ags_recall_unset_behaviour_flags((AgsRecall *) recall, AGS_SOUND_BEHAVIOUR_PERSISTENT);
 
@@ -1452,11 +1449,6 @@ ags_play_lv2_audio_run_run_pre(AgsRecall *recall)
   /*
    * process data
    */
-  /* recycling */
-  g_object_get(selected_channel,
-	       "first-recycling", &recycling,
-	       NULL);
-  g_object_unref(recycling);
 
   /* create audio data */
   g_object_get(destination,
@@ -1521,6 +1513,22 @@ ags_play_lv2_audio_run_run_pre(AgsRecall *recall)
   g_object_unref(play_lv2_audio);
 
   g_object_unref(destination);
+
+  if(start_output != NULL){
+    g_object_unref(start_output);
+  }
+  
+  if(start_input != NULL){
+    g_object_unref(start_input);
+  }
+
+  if(selected_channel != NULL){
+    g_object_unref(selected_channel);
+  }
+
+  if(recycling != NULL){
+    g_object_unref(recycling);
+  }
 }
 
 void
@@ -1530,9 +1538,6 @@ ags_play_lv2_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_run,
 					    AgsPlayLv2AudioRun *play_lv2_audio_run)
 {
   AgsAudio *audio;
-  AgsChannel *output, *input;
-  AgsChannel *channel;
-  AgsChannel *selected_channel;
   AgsNotation *notation;
   AgsNote *note;
   AgsPlayLv2Audio *play_lv2_audio;
@@ -1586,11 +1591,10 @@ ags_play_lv2_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_run,
   /* get audio fields */
   pthread_mutex_lock(audio_mutex);
 
-  output = audio->output;
-  input = audio->input;
-
-  start_list = g_list_copy(audio->notation);
-
+  start_list = g_list_copy_deep(audio->notation,
+				(GCopyFunc) g_object_ref,
+				NULL);
+  
   pthread_mutex_unlock(audio_mutex);
   
   if(start_list == NULL){
@@ -1604,15 +1608,6 @@ ags_play_lv2_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_run,
 
     return;
   }
-
-  /* get channel */
-  if(ags_audio_test_behaviour_flags(audio, AGS_SOUND_BEHAVIOUR_DEFAULTS_TO_INPUT)){
-    selected_channel = ags_channel_nth(input,
-				       audio_channel);
-  }else{
-    selected_channel = ags_channel_nth(output,
-				       audio_channel);
-  }
   
   /* get notation */
   notation = NULL;
@@ -1801,7 +1796,8 @@ ags_play_lv2_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_run,
     remove_note = remove_note->next;
   }
 
-  g_list_free(start_list);
+  g_list_free_full(start_list,
+		   g_object_unref);
   g_list_free_full(start_current_position,
 		   g_object_unref);
   
