@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2018 Joël Krähemann
+ * Copyright (C) 2005-2019 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -886,9 +886,10 @@ ags_play_notation_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_r
 						 AgsPlayNotationAudioRun *play_notation_audio_run)
 {
   AgsAudio *audio;
-  AgsChannel *output, *input;
+  AgsChannel *start_output, *start_input;
   AgsChannel *selected_channel, *channel, *next_pad;
-  AgsRecycling *recycling, *last_recycling;
+  AgsRecycling *first_recycling, *last_recycling;
+  AgsRecycling *recycling, *next_recycling;
   AgsRecycling *end_recycling;
   AgsAudioSignal *audio_signal;
   AgsNotation *notation;
@@ -1014,22 +1015,14 @@ ags_play_notation_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_r
 
       /* recycling */
       g_object_get(selected_channel,
-		   "first-recycling", &recycling,
+		   "first-recycling", &first_recycling,
 		   "last-recycling", &last_recycling,
 		   NULL);
 
-      if(recycling != NULL){
-	g_object_unref(recycling);
-	g_object_unref(last_recycling);
-      }
-      
-      g_object_get(last_recycling,
-		   "next", &end_recycling,
-		   NULL);
+      recycling = first_recycling;
+      g_object_ref(recycling);
 
-      if(end_recycling != NULL){
-	g_object_unref(end_recycling);
-      }
+      end_recycling = ags_recycling_next(last_recycling);
       
       g_object_set(note,
 		   "rt-attack", attack,
@@ -1038,7 +1031,9 @@ ags_play_notation_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_r
 #ifdef AGS_DEBUG	
       g_message("playing[%u|%u]: %u | %u\n", audio_channel, selected_channel->pad, note->x[0], note->y);
 #endif
-	
+
+      next_recycling = NULL;
+      
       while(recycling != end_recycling){
 	g_object_set(note,
 		     "rt-offset", 0,
@@ -1106,13 +1101,27 @@ ags_play_notation_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_r
 	}
 	  
 	/* iterate */
-	g_object_get(recycling,
-		     "next", &recycling,
-		     NULL);
+	next_recycling = ags_recycling_next(recycling);
 
-	if(recycling != NULL){
-	  g_object_unref(recycling);
-	}
+	g_object_unref(recycling);
+
+	recycling = next_recycling;
+      }
+
+      /* unref */
+      g_object_unref(selected_channel);
+
+      if(first_recycling != NULL){
+	g_object_unref(first_recycling);
+	g_object_unref(last_recycling);
+      }
+      
+      if(end_recycling != NULL){
+	g_object_unref(end_recycling);
+      }
+
+      if(next_recycling != NULL){
+	g_object_unref(next_recycling);
       }
 
       /* iterate */
@@ -1177,19 +1186,28 @@ ags_play_notation_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_r
 
   input_pads = audio->input_pads;
   output_pads = audio->output_pads;
-    
-  output = audio->output;
-  input = audio->input;
   
+  start_output = audio->output;
+
+  if(start_output != NULL){
+    g_object_ref(start_output);
+  }
+  
+  start_input = audio->input;
+
+  if(start_input != NULL){
+    g_object_ref(start_input);
+  }
+
   pthread_mutex_unlock(audio_mutex);
 
   /* get channel */
   if(ags_audio_test_behaviour_flags(audio, AGS_SOUND_BEHAVIOUR_DEFAULTS_TO_INPUT)){
-    channel = ags_channel_nth(input,
+    channel = ags_channel_nth(start_input,
 			      audio_channel);
     pads = input_pads;
   }else{
-    channel = ags_channel_nth(output,
+    channel = ags_channel_nth(start_output,
 			      audio_channel);
     pads = output_pads;
   }
@@ -1230,6 +1248,18 @@ ags_play_notation_audio_run_alloc_input_callback(AgsDelayAudioRun *delay_audio_r
 
   g_list_free_full(start_list,
 		   g_object_unref);
+
+  if(start_output != NULL){
+    g_object_unref(start_output);
+  }
+
+  if(start_input != NULL){
+    g_object_unref(start_input);
+  }
+
+  if(channel != NULL){
+    g_object_unref(channel);
+  }
 }
 
 void
